ceph-installer contents
=======================

.. toctree::
   :maxdepth: 2

   index.rst
   cluster.rst


Development
===========

.. toctree::
   :maxdepth: 2

   releasing.rst


Changelog
=========

.. toctree::
   :maxdepth: 2

   changelog.rst

ceph-installer CLI
==================

.. toctree::
   :maxdepth: 2

   man/index.rst
